@@ -212,9 +212,11 @@ fb_sync_contacts_add_timeout(FbData *fata)
 
     sync = set_getint(&acct->set, "sync_interval");
 
-    if (sync < 1) {
-        set_setint(&acct->set, "sync_interval", 1);
-        sync = 1;
+    /* if it's 5 minutes or lower, set it to the new default,
+     * since servers really don't like us syncing that often */
+    if (sync <= 5) {
+        sync = 1440;
+        set_setint(&acct->set, "sync_interval", sync);
     }
 
     sync *= 60 * 1000;
@@ -772,7 +774,7 @@ fb_init(account_t *acct)
     set_add(&acct->set, "mark_read", "false", fb_eval_mark_read, acct);
     set_add(&acct->set, "mark_read_reply", "false", set_eval_bool, acct);
     set_add(&acct->set, "show_unread", "false", set_eval_bool, acct);
-    set_add(&acct->set, "sync_interval", "5", set_eval_int, acct);
+    set_add(&acct->set, "sync_interval", "1440", set_eval_int, acct);
     set_add(&acct->set, "work", "false", set_eval_bool, acct);
 }
 
